<?php

/**
 * @file
 * Timepad Module API File.
 */

namespace Drupal\timepad\Api;

/**
 * Class TimePadApi.
 */
interface TimePadApiInterface {

  /**
   * Get Events List.
   *
   * @param array $params
   *   Public function eventsGetList array params.
   *
   * @return array
   *   Public function eventsGetList array.
   *
   * @throws \Exception
   *
   * @access public
   */
  public function eventsGetList(array $params = []);

  /**
   * Create Event.
   *
   * @param array $params
   *   Public function eventsCreate params.
   *
   * @return array
   *   Public function eventsCreate array.
   *
   * @access public
   */
  public function eventsCreate(array $params);

  /**
   * Edit Event.
   *
   * @param int $event_id
   *   Public function eventsEdit event_id.
   * @param array $params
   *   Public function eventsEdit array params.
   *
   * @return array
   *   Public function eventsEdit array.
   *
   * @access public
   */
  public function eventsEdit($event_id, array $params);

  /**
   * Get Event by it identifier.
   *
   * @param int $event_id
   *   Public function eventsGet event_id.
   * @param array $params
   *   Public function eventsGet array params.
   *
   * @return array|bool
   *   Public function eventsGet array bool.
   *
   * @throws \Exception
   *
   * @access public
   */
  public function eventsGet($event_id, array $params = []);

  /**
   * Create organization.
   *
   * @param array $params
   *   Public function organizationsCreate array params.
   *
   * @return array
   *   Public function organizationsCreate array.
   *
   * @throws \Exception.
   */
  public function organizationsCreate(array $params);

  /**
   * Get information about user account.
   *
   * @return array
   *   Public function accountGet.
   */
  public function accountGet();

  /**
   * Create Order.
   *
   * @param int $event_id
   *   Public function ordersCreate event_id.
   * @param array $params
   *   Public function ordersCreate array params.
   *
   * @return array
   *   Public function ordersCreate array.
   *
   * @access public
   */
  public function ordersCreate($event_id, array $params);

  /**
   * Get Orders List.
   *
   * @param int $event_id
   *   Public function ordersGetList event_id.
   * @param array $params
   *   Public function ordersGetList array params.
   *
   * @return array
   *   Public function ordersGetList array.
   *
   * @access public
   */
  public function ordersGetList($event_id, array $params = []);

  /**
   * Get Order by id.
   *
   * @param int $order_id
   *   Public function ordersGet order_id.
   * @param int $event_id
   *   Public function ordersGet event_id.
   * @param array $params
   *   Public function ordersGet array params.
   *
   * @return array
   *   Public function ordersGet array.
   *
   * @access public
   */
  public function ordersGet($order_id, $event_id, array $params = []);

  /**
   * Get Webhooks List.
   *
   * @param int $organization_id
   *   public function webhooksGetList int organization_id.
   * @param array $params
   *   public function webhooksGetList array params.
   *
   * @return array
   *   public function webhooksGetList array.
   *
   * @access view_private_organizations
   */
  public function webhooksGetList($organization_id, array $params = []);

  /**
   * Create Webhook.
   *
   * @param int $organization_id
   *   Public function webhooksCreate int organization_id.
   * @param array $params
   *   Public function webhooksCreate array params.
   *
   * @return array
   *   Public function webhooksCreate array.
   *
   * @access edit_organizations_hooks
   */
  public function webhooksCreate($organization_id, array $params);

  /**
   * Get Webhook by id.
   *
   * @param int $hook_id
   *   Public function webhooksGet int hook_id.
   * @param int $organization_id
   *   Public function webhooksGet int organization_id.
   * @param int $event_id
   *   Public function webhooksGet int event_id.
   * @param array $params
   *   Public function webhooksGet array params.
   *
   * @return array
   *   Public function webhooksGet array.
   *
   * @access view_private_organizations
   */
  public function webhooksGet($hook_id, $organization_id, array $params = []);

  /**
   * Edit Webhook.
   *
   * @param int $hook_id
   *   Public function webhooksEdit int hook_id.
   * @param int $organization_id
   *   Public function webhooksEdit int organization_id.
   * @param array $params
   *   Public function webhooksEdit array params.
   *
   * @return array
   *   Public function webhooksEdit array.
   *
   * @access edit_organizations_hooks
   */
  public function webhooksEdit($hook_id, $organization_id, array $params);

}
