<?php

namespace Drupal\timepad\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\timepad\Api\TimePadApiInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class TimepadEventsDashboard
 * @package Drupal\timepad\Controller
 */
class TimepadEventsDashboard extends ControllerBase {

  /**
   * TimePad Api.
   *
   * @var \Drupal\timepad\Api\TimePadApiInterface
   */
  protected $timePadApi;

  /**
   * {@inheritdoc}
   */
  public function __construct(TimePadApiInterface $timePadApi) {
    $this->timePadApi = $timePadApi;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('timepad.api')
    );
  }

  /**
   * Dashboard of events from TimePad.
   */
  public function dashboard() {
    $items_per_page = 20;

    $account = $this->timePadApi->accountGet();

    // @todo: Add filter by organizations.
    $organizations = array();
    foreach ($account['organizations'] as $item) {
      $organizations[] = $item['id'];
    }

    $filters = array(
      'fields' => array(
        'name',
        'id',
        'starts_at',
        'ends_at',
        'location',
        'url',
      ),
      'limit' => $items_per_page,
    );

    // Add organizations.
    if ($organizations) {
      $filters['organization_ids'] = $organizations;
    }

    // Add pager to request.
    if (isset($_GET['page']) && $_GET['page'] > 0) {
      $filters['skip'] = $_GET['page'] * $items_per_page;
    }

    // Add sort to request.
    if (isset($_GET['sort']) && $_GET['sort'] === 'desc') {
      $sort_type = '-';
    }
    else {
      $sort_type = '+';
    }
    $field_sort = 'starts_at';
    if (isset($_GET['order'])) {
      switch ($_GET['order']) {
        case t('Title'):
          $field_sort = 'name';
          break;

        case t('Date'):
          $field_sort = 'starts_at';
          break;

        case t('City'):
          $field_sort = 'city';
          break;
      }
    }
    $filters['sort'] = $sort_type . $field_sort;
    $result = $this->timePadApi->eventsGetList($filters);

    // Build table of result data.
    $table = array(
      'header' => array(
        'title' => array(
          'data' => t('Title'),
          'field' => 'name',
        ),
        'date' => array(
          'data' => t('Date'),
          'field' => 'starts_at',
          'sort' => 'asc',
        ),
        'country' => t('Country'),
        'city' => array(
          'data' => t('City'),
          'field' => 'city',
        ),
        'address' => t('Address'),
        'url' => t('Link to TimePad'),
        'actions' => t('Actions'),
      ),
    );
    $rows = array();
    foreach ($result['values'] as $item) {
      $date_obj = date_create_from_format('Y-m-d\TH:i:sP', $item['starts_at']);
      $date = $date_obj->format('d.m.Y, H:i');

      if (isset($item['ends_at'])) {
        $date_obj = date_create_from_format('Y-m-d\TH:i:sP', $item['ends_at']);
        $date .= ' - ' . $date_obj->format('d.m.Y, H:i');
      }

      $actions = array(
        l(t('view'), 'timepad-event/' . $item['id']),
        l(t('edit'), 'timepad-event/' . $item['id'] . '/edit'),
      );

      $rows[] = array(
        'title' => l($item['name'], 'timepad-event/' . $item['id']),
        'date' => $date,
        'country' => !empty($item['location']['country']) ? $item['location']['country'] : '',
        'city' => !empty($item['location']['city']) ? $item['location']['city'] : '',
        'address' => !empty($item['location']['address']) ? $item['location']['address'] : '',
        'url' => l(t('link'), $item['url'], array('external' => TRUE, 'attributes' => ['target' => '_blank'])),
        'actions' => implode(' ', $actions),
      );
    }

    $table['rows'] = $rows;

    $html = theme('table', $table);

    pager_default_initialize($result['total'], $items_per_page);
    $html .= theme('pager', array('tags' => NULL));

    return $html;
  }

}
